@@ -18,7 +18,7 @@ import cairo
 import msgpack
 
 
-VERSION = '0.0.4'
+VERSION = '0.0.6'
 
 
 class B8Object:
@@ -487,48 +487,6 @@ class Terminals(B8View):
     t.start(wd)
 
 
-class Interactive(code.InteractiveInterpreter):
-
-  ps1 = b'b8 >>> '
-  ps2 = b'b8 ... '
-
-
-  def __init__(self, b8, term_view):
-    self.b8 = b8
-    self.term_view = term_view
-    code.InteractiveInterpreter.__init__(self, locals={'b8': b8})
-    self.term_view.term.feed(b'bominade interactive console\r\n')
-    self.term_view.term.feed(self.prompt)
-    self.term_view.term.connect('commit', self.on_commit)
-    self.buffer = []
-
-  def on_commit(self, w, text, size):
-    print(w, [text], size)
-    to_show = text.replace('\r', '\r\n')
-    self.buffer.append(to_show)
-    self.term_view.term.feed(to_show.encode('utf-8'))
-    if text == '\r':
-      line = ''.join(self.buffer)
-      print([line])
-      oldstdout = sys.stdout
-      newstdout = io.StringIO()
-      sys.stdout = newstdout
-      more = self.runsource(line)
-      sys.stdout = oldstdout
-      if more:
-        self.prompt = self.ps2
-      else:
-        self.prompt = self.ps1
-        self.buffer = []
-        newstdout.seek(0)
-        reply = newstdout.read().replace('\n', '\r\n')
-        self.term_view.term.feed(reply.encode('utf-8'))
-      self.term_view.term.feed(self.prompt)
-
-  def write(self, data):
-    print('data', data)
-    self.term_view.term.feed(data.encode('utf-8'))
-
 
 class Console(B8View):
 
@@ -803,7 +761,7 @@ class Buffer:
   number = ''
 
   def __init__(self, path, number):
-    self.path = path
+    self.path = os.path.realpath(path)
     self.number = number
     self.name = os.path.basename(path)
     self.parent = os.path.dirname(path)
@@ -859,7 +817,6 @@ class Buffers(B8View):
   def remove(self, path, number):
     for grow in self.model:
       b = self.model.get_value(grow.iter, 0)
-
       if b.number == number and b.path == path:
         self.model.remove(grow.iter)
         return
@@ -1289,15 +1246,15 @@ class Vim(B8Object):
   def on_buffers(self, opts):
     action = opts[0]
     buffer_number = int(opts[1])
-    buffer_path = opts[2]
+    vim_path = opts[2]
+    if not vim_path:
+      # New files and things
+      return 
+    buffer_path = os.path.realpath(vim_path)
     self.debug(f'buffers {action} {buffer_number} {buffer_path}')
     if action == 'enter':
-      if not buffer_path:
-        return
       self.b8.buffers.change(buffer_path, buffer_number)
     elif action == 'delete':
-      if not buffer_path:
-        return
       self.b8.buffers.remove(buffer_path, buffer_number)
 
 
